@@ -3,10 +3,10 @@
  * template.
  */
 
-var ejs = require('../')
-  , read = require('fs').readFileSync
-  , join = require('path').join
-  , str = read(join(__dirname, '/list.ejs'), 'utf8');
+var ejs = require('../');
+var read = require('fs').readFileSync;
+var join = require('path').join;
+var str = read(join(__dirname, '/list.ejs'), 'utf8');
 
 var ret = ejs.compile(str)({
   names: ['foo', 'bar', 'baz']
